==> iotedgehubdev-0.1.0-py2.py3-none-any.whl: iotedgehubdev/telemetry_upload.py <==
try:
    # Python 2.x
    import urllib2 as HTTPClient
except ImportError:
    # Python 3.x
    import urllib.request as HTTPClient

import sys
import json
import six

from applicationinsights import TelemetryClient
from applicationinsights.exceptions import enable
from applicationinsights.channel import SynchronousSender, SynchronousQueue, TelemetryChannel
from iotedgehubdev import decorators


class LimitedRetrySender(SynchronousSender):
    def __init__(self):
        super(LimitedRetrySender, self).__init__()

    def send(self, data_to_send):
        """ Override the default resend mechanism in SenderBase. Stop resend when it fails."""
        request_payload = json.dumps([a.write() for a in data_to_send])

        request = HTTPClient.Request(self._service_endpoint_uri, bytearray(request_payload, 'utf-8'),
                                     {'Accept': 'application/json', 'Content-Type': 'application/json; charset=utf-8'})
        try:
            HTTPClient.urlopen(request, timeout=10)
        except Exception:  # pylint: disable=broad-except
            pass


@decorators.suppress_all_exceptions()
def upload(data_to_save):
    try:
        data_to_save = json.loads(data_to_save.replace("'", '"'))
    except Exception:
        pass

    for instrumentation_key in data_to_save:
        client = TelemetryClient(instrumentation_key=instrumentation_key,
                                 telemetry_channel=TelemetryChannel(queue=SynchronousQueue(LimitedRetrySender())))
        enable(instrumentation_key)
        for record in data_to_save[instrumentation_key]:
            name = record['name']
            raw_properties = record['properties']
            properties = {}
            measurements = {}
            for k, v in raw_properties.items():
                if isinstance(v, six.string_types):
                    properties[k] = v
                else:
                    measurements[k] = v
            client.track_event(name, properties, measurements)
        client.flush()


if __name__ == '__main__':
    # If user doesn't agree to upload telemetry, this scripts won't be executed. The caller should control.
    upload(sys.argv[1])

==> iotedgehubdev-0.2.0-py2.py3-none-any.whl: iotedgehubdev/telemetry_upload.py <==
try:
    # Python 2.x
    import urllib2 as HTTPClient
except ImportError:
    # Python 3.x
    import urllib.request as HTTPClient

import sys
import json
import six

from applicationinsights import TelemetryClient
from applicationinsights.exceptions import enable
from applicationinsights.channel import SynchronousSender, SynchronousQueue, TelemetryChannel
from iotedgehubdev import decorators


class LimitedRetrySender(SynchronousSender):
    def __init__(self):
        super(LimitedRetrySender, self).__init__()

    def send(self, data_to_send):
        """ Override the default resend mechanism in SenderBase. Stop resend when it fails."""
        request_payload = json.dumps([a.write() for a in data_to_send])

        request = HTTPClient.Request(self._service_endpoint_uri, bytearray(request_payload, 'utf-8'),
                                     {'Accept': 'application/json', 'Content-Type': 'application/json; charset=utf-8'})
        try:
            HTTPClient.urlopen(request, timeout=10)
        except Exception:  # pylint: disable=broad-except
            pass


@decorators.suppress_all_exceptions()
def upload(data_to_save):
    try:
        data_to_save = json.loads(data_to_save)
    except Exception:
        pass

    for instrumentation_key in data_to_save:
        client = TelemetryClient(instrumentation_key=instrumentation_key,
                                 telemetry_channel=TelemetryChannel(queue=SynchronousQueue(LimitedRetrySender())))
        enable(instrumentation_key)
        for record in data_to_save[instrumentation_key]:
            name = record['name']
            raw_properties = record['properties']
            properties = {}
            measurements = {}
            for k, v in raw_properties.items():
                if isinstance(v, six.string_types):
                    properties[k] = v
                else:
                    measurements[k] = v
            client.track_event(name, properties, measurements)
        client.flush()


if __name__ == '__main__':
    # If user doesn't agree to upload telemetry, this scripts won't be executed. The caller should control.
    upload(sys.argv[1])
